@@ -2,7 +2,7 @@ package Text::Undiacritic;
 
 use strict;
 use warnings;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 require Exporter;
 our @ISA = qw(Exporter); ## no critic
@@ -25,7 +25,8 @@ sub undiacritic {
         ? do {
           my $charname = charnames::viacode(ord $_);
           $charname =~ s/\s WITH \s .+ \z//x;
-          charnames::string_vianame($charname);
+          #charnames::string_vianame($charname);
+          chr charnames::vianame($charname);
         }
         : $_;
     }
